#! /bin/bash
#
# written by Rainer Wanke, June 1998, based on itr_collect.sh
# written by Thorsten Glebe, November 1997
# Max-Planck-Institut of Nuclear Physics
# Heidelberg / Germany
#
# modified by Thorsten Glebe, Jan. 1999
#
# 1. argument: directory where to copy all the stuff (optional)
#

DIR=`dirname $0`
source $DIR/util.sh

if [ $# -gt 1 ]; then
    echo "usage: $PROG <directory>"
    exit 1
fi


if [ $# -eq 1 ]; then
  AR_DIR=${1}/${HBBINTYPE}/lib
else
  AR_DIR=${LIBROOT}/${HBBINTYPE}/lib
fi

ARCHIVE=libitr.a
PACK_FILE=$LIBROOT/PACKAGES

#
# create AR_DIR, if not yet existing
#
if [ ! -d "$AR_DIR" ]; then
  echo "creating $AR_DIR..."
  mkdir -p $AR_DIR
  check_status "error creating $AR_DIR"
fi

#
# remove old ITRlib library file
#
if [ -f "$AR_DIR/$ARCHIVE" ]; then
  echo "Archive $AR_DIR/$ARCHIVE already exists, removing it!"
  rm $AR_DIR/$ARCHIVE
  check_status "error removing $AR_DIR/$ARCHIVE"
fi

#
# collect object files and build archive
#
for i in `cat $PACK_FILE | ${AWK} '!/^[ ]*#.*$/ && ($2 ~ /\/[0-9]+-[0-9]+/ || $2 ~ /dev/) {gsub("/",".",$2); print $1"+"substr($2,2)}'`; do
    NAME=`echo $i | cut -d+ -f1`
    VERS=`echo $i | cut -d+ -f2`
    if [ $VERS = dev ] ; then
	LIBNAME=$ITRROOT/packages/$NAME/$VERS/lib.$HBBINTYPE
    else
	LIBNAME=$ITRROOT/packages/$NAME/$NAME$VERS/lib.$HBBINTYPE
    fi
    if [ -d "$LIBNAME" ]; then
      find $LIBNAME -name *\\.o -print -exec ar rc $AR_DIR/$ARCHIVE {} \;
    else
      echo "$LIBNAME does not exist..."
    fi
done

exit 0
