#
# Script to be sourced by ITRlib scripts
#
# Utility functions, T. Glebe September 1999

PROG=`basename $0`

if [ -z ${ITRROOT} ]; then
  ITRROOT=${HBROOT}/ITR
  echo "ITRROOT was not defined => set to ${ITRROOT}"
fi

if [ "$DIR" = "." ]; then
  export LIBROOT=`pwd`
else
  export LIBROOT=$DIR
fi

# let Makefile use the default settings
export ITRLIB_DEFAULT="yes"

#######################################
#         check_status()              #
# 1. argument: exit status ($?)       #
# 2. argument: error message (string) #
#######################################
check_status(){
if [ $? -ne 0 ]; then
  echo $1 >&2
  echo $1 >> $LIBROOT/ERRORS
  exit 1
fi
}
#######################################

#######################################
#         warn()                      #
# 1. argument: warn  message (string) #
#######################################
warn(){
  echo "$PROG WARNING: $1" >&2
  echo "$PROG WARNING: $1" >> $LIBROOT/ERRORS
}
#######################################

#######################################
#         error()                     #
# 1. argument: error message (string) #
#######################################
error(){
  echo "$PROG ERROR: $1" >&2
  echo "$PROG ERROR: $1" >> $LIBROOT/ERRORS
  exit 1
}
#######################################

#######################################
#         set_make()                  #
#######################################
set_make() {
  $LIBROOT/itr_command.sh gmake 1>/dev/null
  if [ $? -eq 0 ]; then
    MAKE=gmake
  else
    MAKE=make
  fi
  export MAKE
}
#######################################

#######################################
#         set_xcvs()                  #
#######################################
set_xcvs() {
  XCVS=`$LIBROOT/itr_command.sh xcvs`
  check_status "error: xcvs not found"
  export XCVS
}
#######################################

#######################################
#         set_tar()                   #
#######################################
set_tar() {
  $LIBROOT/itr_command.sh gtar
  if [ $? -eq 0 ]; then
     TAR=gtar
  else
  TAR=tar
  fi
  export TAR
}
#######################################

if [ -z "$HBBINTYPE" ]; then
    echo "HBBINTYPE not defined!!"
    exit 1
fi

if [ ! -d "$ITRROOT" ]; then
   echo "directory $ITRROOT not existing!"
   exit 1
fi

if [ ! -f $LIBROOT/PACKAGES ]; then
  error "Can not find $LIBROOT/PACKAGES!"
fi


export AWK=gawk
