#ifndef __ITRLEDA_STRUCTS_H__
#define __ITRLEDA_STRUCTS_H__


#include "iol.h"


#ifdef __cplusplus
extern "C" {
#endif


#ifndef LCHAMBERNAME
#define LCHAMBERNAME 50
#endif

#ifndef NCHIPCHAN
#define NCHIPCHAN 128
#endif


typedef struct {
  unsigned short id;
  unsigned char  ncellped;
  unsigned char  ncellnoise;
  signed   char  status;
  unsigned char  pipelen;
  unsigned short fed;
  unsigned short chamber;
} itrleda_Chip_t;


typedef struct {
  unsigned short id;
  unsigned char  vmeid;
  unsigned char  board;
  unsigned char  sharc;
  unsigned char  link;
  unsigned short chip[2];
} itrleda_Fed_t;


typedef struct {
  unsigned short id;
  char           name[LCHAMBERNAME];
  signed char    align_flag;
  signed char    status;
  unsigned char  type;
  unsigned short chip[6];
  unsigned short align;
  unsigned short tonede;
} itrleda_Chamber_t;


typedef struct {
  unsigned short chipid;
  unsigned char  status[NCHIPCHAN];
} itrleda_Chanstat_t;


typedef struct {
  unsigned short chipid;
  short    int   pedestal [NCHIPCHAN];
} itrleda_Ped_t;


typedef struct {
  unsigned short chipid;
  float          rawvar [NCHIPCHAN];
  float          subvar [NCHIPCHAN];
} itrleda_Noise_t;


typedef struct {
  unsigned short id;          
  int            nede;
  float          ang  [3];   
  float          eang [3];   
  float          delt [3];   
  float          edelt[3];   
  float          sloff[3];   
  float        	 esloff[3];  
  float          redres;      
} itrleda_Align_t;


typedef struct {
  unsigned short chamber;
  int            offset;
} itrleda_DVOffset_t;


typedef struct {
  int   inede;
  float rot_db[9];
  float xfw_db[2];
  float zfw_db;
  int   nwi_db[2];
  float xmin_db[2];
  float xmax_db[2];
  float ymin_db[2];
  float ymax_db[2];
  float zmin_db;
  float zmax_db;
  float sxmn_db[2];
  float sxmx_db[2];
  float symx_db[2];
  float symn_db[2];
  float acc_db;
  float eff_db;
  float dod_db;
  float pit_db;
  float ms_db;
  int   nsl_db;     /* Number of sublayers in a segment */
  int   superl_db;  /* GESLsyperlayer */
  int   lay_db;     /* layer */
  int   sec_db[2];  /* sector */
  float dedx_db;
  char  hwc_db[13];
  int noise_db;
  int ares_db;
  int tonesl;     /* relation container */
  unsigned short tochamber;  /* relation to chamber table */
  unsigned short toalign;    /* relation to alignment table */
} itrleda_nede_t;


typedef struct {
  int inesl;
  int nsl;
  int mfl;
  int lay;
  float x1;
  float x2;
  float y1;
  float y2;
  float z1;
  float z2;
  float dx;
  float dy;
  int npl;
  int fpl;
  int nwl;
  int fwl;
  int ltyp;
  int pnede;
  char name[5];
  int tonede; /* relation container */
} itrleda_nesl_t;


#define MAX_FMT_CHIPS    1104
#define MAX_FMT_CHAMBERS  184
#define MAX_FMT_ALIGN     MAX_FMT_CHAMBERS
#define MAX_FMT_NEDE    (2*MAX_FMT_CHAMBERS)
#define MAX_FMT_NESL       10
#define MAX_FMT_FEDS      552

#ifdef FMT_SENDS_IOL_PARAMS
#define MAX_FMT_PARAMS    200
#endif
/* structure holding the complete information : 
 * this is the CIF formatted table               */

typedef struct {
  int  major;
  int  minor;
  char date[200];
  int  number;

  int  nChambers;
  itrleda_Chamber_t  chambers[MAX_FMT_CHAMBERS];

  int  nFeds;
  itrleda_Fed_t      fed[MAX_FMT_FEDS];

  int  nChips;
  itrleda_Chip_t     chips[MAX_FMT_CHIPS];

  int  nChanstat;
  itrleda_Chanstat_t chanstat[MAX_FMT_CHIPS];

  int  nPed;
  itrleda_Ped_t      ped[MAX_FMT_CHIPS];

  int  nNoise;
  itrleda_Noise_t    noise[MAX_FMT_CHIPS];

  int  nAlign;
  itrleda_Align_t    align[MAX_FMT_ALIGN];

  int  nNesl;
  itrleda_nesl_t     nesl[MAX_FMT_NESL];
  
  int  nNede;
  itrleda_nede_t     nede[MAX_FMT_NEDE];

  int  nOffsets;
  itrleda_DVOffset_t DVOffset[MAX_FMT_CHAMBERS];

#ifdef FMT_SENDS_IOL_PARAMS
  int  nParams;
  iol_param_t        iolparams[MAX_FMT_PARAMS];
#endif

} itrleda_fmtTable_t;

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /*__ITRLEDA_STRUCTS_H__*/
