/* ---------------------------------------------------------------
 *
 *  fill channel map list with values stored in database
 *  and retrieved by LEDA
 *
 *  Returned is the pointer to the first channel map
 *
 *  Function argument:
 *     int *nmap;    // number of maps
 *
 *  CHANGES:  see also file CHANGES
 *      Dec. 01 (wg)  introduce database with datavalid offsets
 *
 * --------------------------------------------------------------- */

#include <iostream.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "component.h"
#include "grr.h"

#include "aframelib.h"

#include "ledaC++.hh"
#include "itrleda.h"
#include "itrleda_dd.h"
#include "ITR_silraw.h"
#include "itrMAP.h"

#define NCHIPCHAN      128
#define MAXMAP         1024
#define MAXFEDCHAN    (2*NCHIPCHAN)

ITR_map* itrslt_fillMAP( int* nmap )  {
    char *routine = "itrslt_fillMAP";

    static ITR_map* itrmap = NULL;  /* pointer to MAP */
    
    /* define a LEDA table iterator for looping over FEDs */
    LedaTableIterator<class ITR_Chamber> chamberIt;
    
    /* initialize map counter */
    *nmap = 0;
    
    /* allocate space for MAP table */
    if ( itrmap == NULL ) {
	itrmap = (ITR_map*) calloc( sizeof(ITR_map), MAXMAP );
	if ( itrmap == NULL ) {
	    aframe_mess(routine,GRR_SERROR,
			"Could not allocate space for ITR_map table");
	    return NULL;
	}
    }
    
    //  const int kOffset      = 8;
    const int kBitsInColNo = 8;
    int iOffset;
    
    int cnt    = 0;
    int oldFED = -1, chipNo;
    
    /* loop over Chamber entries in LEDA */
    for (  ; chamberIt.valid(); chamberIt.next() ) {
	LedaPointer<class ITR_Chamber>  chamber = chamberIt.get();
	LedaRelationIterator chipIt (chamber->chip);
	LedaPointer<class ITR_nede> nede = chamber->tonede;
	LedaPointer<class ITR_nesl> nesl = nede->tonesl;
	
	int nWi = 0;
	int wireoffset;
	
	if (chamber->type == 3)
	    wireoffset = 5; 
	else
	    wireoffset = 8;
	
	for (chipNo = 0 ; chipIt.valid() && cnt < MAXMAP; chipIt.next(), chipNo++) {
	    LedaPointer<class ITR_Chip>   chip (chipIt);
	    LedaPointer<class ITR_Fed>    fed    = chip->fed;
	    
	    LedaTableIterator <class ITR_FedSlb> fedslb_it;
	    LedaPointer<class ITR_FedSlb> fedslb;
	    int slbfound = 0;
	    for (; fedslb_it.valid(); fedslb_it.next()) {
		fedslb = fedslb_it.get();
		if (fedslb->fedid == fed->id) { 
		    slbfound = 1;
		    break;
		}
	    }
	    
	    // we need a bufmap entry for each chip!
	    if (cnt >= MAXMAP) {
		cout << "too many maps! " << endl;
		break;
	    }
	    
	    /* obtain datavalid offset for this FED */
	    iOffset = ITR_leda_getDVOffset (chamber->id); 

	    strncpy(itrmap[cnt].spl, nesl->name, 5);
	    itrmap[cnt].cid    = COMP_N_ITR;
	    itrmap[cnt].sl     = nede->superl_db;
	    itrmap[cnt].lay    = nede->lay_db;
	    itrmap[cnt].sec    = nede->sec_db[0];
	    itrmap[cnt].fedid  = fed ->id;
	    itrmap[cnt].vmeid  = fed ->vmeid;
	    itrmap[cnt].board  = fed ->board;
	    itrmap[cnt].sharc  = fed ->sharc;
	    itrmap[cnt].link   = 0;              /* DAQ ID to be filled in here! */
	    itrmap[cnt].daqid  = (slbfound) ? fedslb->slbid : -1;
	    
	    
	    switch (chipNo) {
	    case 0:     // first chip:  some channels are not bonded to chamber
		itrmap[cnt].chan1  = iOffset + wireoffset; /* take offset from DB! */
		itrmap[cnt].chan2  = iOffset + NCHIPCHAN;
		
		itrmap[cnt].wire1  = 0;
		itrmap[cnt].wire2  = NCHIPCHAN - wireoffset - 1;
		nWi = NCHIPCHAN - wireoffset;
		break;
	    case 2:     // first chip in an FED
	    case 4:
		itrmap[cnt].chan1  = iOffset; /* take offset from DB! */
		itrmap[cnt].chan2  = iOffset + NCHIPCHAN - 1;
		
		itrmap[cnt].wire1  = nWi;
		itrmap[cnt].wire2  = nWi + NCHIPCHAN - 1;
		nWi += NCHIPCHAN;
		break;
		
	    case 1:
	    case 3:
		/* take offset from DB! */  
		itrmap[cnt].chan1  = iOffset + NCHIPCHAN + kBitsInColNo;
		itrmap[cnt].chan2  = itrmap[cnt].chan1   + NCHIPCHAN - 1;
		itrmap[cnt].wire1  = nWi;
		itrmap[cnt].wire2  = nWi + NCHIPCHAN - 1;
		nWi += NCHIPCHAN;
		break;
		
	    case 5:     // last chip:  some channels are not bonded to chamber
		/* take offset from DB! */
		itrmap[cnt].chan1  = iOffset + NCHIPCHAN + kBitsInColNo; 
		itrmap[cnt].chan2  = itrmap[cnt].chan1 + NCHIPCHAN - wireoffset - 1;
		itrmap[cnt].wire1  = nWi;
		itrmap[cnt].wire2  = nWi + NCHIPCHAN - wireoffset - 1;
		nWi += NCHIPCHAN - wireoffset;
	    }
	    
	    cnt ++;
	    
	} /* end loop over Chips */
    }  /* end loop over Chambers */
    
    *nmap = cnt;
    return itrmap;
}



/* To make (X)Emacs behave nicely:
 *
 * Local variables:
 *  c-basic-offset: 4
 * End:
 */

